package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// InvoiceCenterList
// @Summary    	 发票列表
// @Tags         发票中心------嘉俊
// @Description  发票中心-发票列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.InvoiceCenterDataReq   true   "请求参数"
// @Success      200   {object}	  md.InvoiceCenterDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/invoiceCenter/list [POST]
func InvoiceCenterList(c *gin.Context) {
	var req md.InvoiceCenterDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.InvoiceCenterList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// InvoiceCenterDetail
// @Summary    	 发票详情
// @Tags         发票中心------嘉俊
// @Description  发票中心-发票详情
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.CommDetailReq   true   "请求参数"
// @Success      200   {object}	  md.InvoiceCenterDataDetailRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/invoiceCenter/detail [POST]
func InvoiceCenterDetail(c *gin.Context) {
	var req md.CommDetailReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.InvoiceCenterDetail(c, req)
	e.OutSuc(c, res, nil)
	return
}
